import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/equipment-monitoring',
    children: [
      {
        path: 'equipment-monitoring',
        name: 'equipment-monitoring',
        // redirect: '/equipment-monitoring/fire-alarm',
        redirect: '/equipment-monitoring/alarm-mo',
        component: () => import('@/views/equipment-monitoring/index'),
        meta: { title: '设备监控' },
        children: [
          {
            path: 'fire-alarm',
            name: 'fire-alarm',
            component: () => import('@/views/equipment-monitoring/fire-alarm/index'),
            meta: { title: '火灾自动报警系统' }
          },
          {
            path: 'fire-water',
            name: 'fire-water',
            component: () => import('@/views/equipment-monitoring/fire-water/index'),
            meta: { title: '消防给水监测系统' }
          },
          {
            path: 'ele-fire',
            name: 'ele-fire',
            component: () => import('@/views/equipment-monitoring/ele-fire/index'),
            meta: { title: '电气火灾智能监控系统' }
          },
          {
            path: 'gas-mo',
            name: 'gas-mo',
            component: () => import('@/views/equipment-monitoring/gas-mo/index'),
            meta: { title: '可燃气体检测预警系统' }
          },
          {
            path: 'alarm-mo',
            name: 'alarm-mo',
            component: () => import('@/views/equipment-monitoring/alarm-mo/index'),
            meta: { title: '无线火灾报警监控系统' }
          },
          {
            path: 'video-ai',
            name: 'video-ai',
            component: () => import('@/views/equipment-monitoring/video-ai/index'),
            meta: { title: '视频AI系统' }
          }
        ]
      },
      {
        path: 'alarm-statistics',
        name: 'alarm-statistics',
        component: () => import('@/views/alarm-statistics/index'),
        meta: { title: '报警统计' },
        children: []
      }
    ]
  },
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
