// http://gavin0212.imwork.net/3rd/bigScreenData/bigScreenMessage?gId=133783305191425&cId=133783305191425&path=fireData1
//     http://gavin0212.imwork.net/3rd/bigScreenData/bigScreenMessage?gId=133783305191425&cId=133783305191425&path=fireData2
import { dateUtils } from 'happy-utils'
import websocketFn from '@/utils/ws'

/**
 * 1：用户信息传输装置     这个就是网站上的:火灾自动报警系统
 2：电气火灾监控器                        电气火灾智能监控系统
 3：液位
 4：水压                 3和4就是网站上的: 消防给水监测系统
 5：燃气                 本次用不到
 6：无线烟感                                 无线火灾报警监控系统
 * @param params
 * @returns {AxiosPromise}
 */

import { getEquipmentMonitoringData } from '@/api/equipment-monitoring'
import { getReqParam } from '@/utils/auth'

const getDefaultState = () => {
  return {
    freAlarmData: null, // 火灾自动报警系统
    fireWaterData: null, // 消防给水监测系统
    eleFireData: null, // 电气火灾智能监控系统
    gasMoData: null, // 可燃气体检测预警系统
    alarmMoData: null, // 无线火灾报警监控系统
    freAlarmStatisticsData: null, // 火灾自动报警系统 - 统计数据
    fireWaterStatisticsData: null, // 消防给水监测系统 - 统计数据
    eleFireStatisticsData: null, // 电气火灾智能监控系统 - 统计数据
    gasMoStatisticsData: null, // 可燃气体检测预警系统 - 统计数据
    alarmMoStatisticsData: null // 无线火灾报警监控系统 - 统计数据
  }
}

const state = getDefaultState()

const mutations = {
  RESET_freAlarmStatisticsData: (state, data) => {
    state.freAlarmStatisticsData = data
  },
  RESET_fireWaterStatisticsData: (state, data) => {
    state.fireWaterStatisticsData = data
  },
  RESET_eleFireStatisticsData: (state, data) => {
    state.eleFireStatisticsData = data
  },
  RESET_gasMoStatisticsData: (state, data) => {
    state.gasMoStatisticsData = data
  },
  RESET_alarmMoStatisticsData: (state, data) => {
    state.alarmMoStatisticsData = data
  },
  RESET_freAlarmData: (state, data) => {
    state.freAlarmData = data
  },
  RESET_fireWaterData: (state, data) => {
    state.fireWaterData = data
  },
  RESET_fireWaterData_fireData3: (state, data) => {
    const temp = state.fireWaterData
    if (temp) {
      state.fireWaterData = {
        fireData3: data,
        fireData4: temp.fireData4
      }
    } else {
      state.fireWaterData = {
        fireData3: data,
        fireData4: null
      }
    }
  },
  RESET_fireWaterData_fireData4: (state, data) => {
    const temp = state.fireWaterData
    if (temp) {
      state.fireWaterData = {
        fireData3: temp.fireData3,
        fireData4: data
      }
    } else {
      state.fireWaterData = {
        fireData3: null,
        fireData4: data
      }
    }
  },
  RESET_eleFireData: (state, data) => {
    state.eleFireData = data
  },
  RESET_gasMoData: (state, data) => {
    state.gasModata = data
  },
  RESET_alarmMoData: (state, data) => {
    state.alarmMoData = data
  }
}

const actions = {
  /** ************     ws start        ****************/
  /**
     * 火灾自动报警系统
     * @param params
     * @returns {AxiosPromise}
     */
  wsFireAlarmData({ commit, state }) {
    const { cId, gId } = getReqParam()
    websocketFn({ gId: gId, cId: cId, path: 'fireData1' }, (response) => {
      const { data } = response
      const parseData = JSON.parse(data)
      if (parseData.fireData) {
        parseData.fireData[0].forEach(item => {
          item.viewInfo = JSON.parse(item.viewInfo)
        })
      }
      console.log('wsFireAlarmData', parseData.fireData[0])
      commit('RESET_freAlarmData', parseData)
    })
  },

  /**
     * 消防给水监测系统
     * @param params
     * @returns {AxiosPromise}
     */
  wsFireWaterData({ commit, state }) {
    const { cId, gId } = getReqParam()
    websocketFn({ gId: gId, cId: cId, path: 'fireData3' }, (response) => {
      const { data } = response
      const parseData = JSON.parse(data)
      if (parseData.fireData) {
        parseData.fireData[0].forEach(item => {
          item.viewInfo = JSON.parse(item.viewInfo)
          if (item.last7DayDatas) {
            const names = []; const values = []
            item.last7DayDatas.forEach((cItem) => {
              names.push(dateUtils.dateFormat(new Date(cItem.occurTime), 'yyyy-MM-dd'))
              // values.push(cItem.actVal.replace(item.viewInfo.unit,''))
              values.push(cItem.actVal.replace(item.viewInfo.unit, ''))
            })
            item.names = names
            item.values = values
          }
        })
      }
      console.log('wsFireWaterData_fireData3', parseData.fireData[0])
      commit('RESET_fireWaterData_fireData3', parseData)
    })
    websocketFn({ gId: gId, cId: cId, path: 'fireData4' }, (response) => {
      const { data } = response
      const parseData = JSON.parse(data)
      if (parseData.fireData) {
        parseData.fireData[0].forEach(item => {
          item.viewInfo = JSON.parse(item.viewInfo)
          if (item.last7DayDatas) {
            const names = []; const values = []
            item.last7DayDatas.forEach((cItem) => {
              names.push(dateUtils.dateFormat(new Date(cItem.occurTime), 'yyyy-MM-dd'))
              // values.push(cItem.actVal.replace(item.viewInfo.unit,''))
              values.push(cItem.actVal.replace(item.viewInfo.unit, ''))
            })
            item.names = names
            item.values = values
          }
        })
      }
      console.log('wsFireWaterData_fireData4', parseData.fireData[0])
      commit('RESET_fireWaterData_fireData4', parseData)
    })
  },

  /**
     * 电气火灾智能监控系统
     * @param params
     * @returns {AxiosPromise}
     */
  wsEleFireData({ commit, state }) {
    const { cId, gId } = getReqParam()
    websocketFn({ gId: gId, cId: cId, path: 'fireData2' }, (response) => {
      const { data } = response
      const parseData = JSON.parse(data)
      if (parseData.fireData) {
        parseData.fireData[0].forEach(item => {
          item.viewInfo = JSON.parse(item.viewInfo)
        })
      }
      console.log('wsEleFireData', parseData.fireData[0])
      commit('RESET_eleFireData', parseData)
    })
  },

  /**
     * 可燃气体检测预警系统
     * @param params
     * @returns {AxiosPromise}
     */
  wsGasMoData({ commit, state }) {
    const { cId, gId } = getReqParam()
    websocketFn({ gId: gId, cId: cId, path: 'fireData5' }, (response) => {
      const { data } = response
      const parseData = JSON.parse(data)
      if (parseData.fireData) {
        parseData.fireData[0].forEach(item => {
          item.viewInfo = JSON.parse(item.viewInfo)
        })
      }
      console.log('wsGasMoData', parseData.fireData[0])
      commit('RESET_gasMoData', parseData)
    })
  },

  /**
     * 无线火灾报警监控系统
     * @param params
     * @returns {AxiosPromise}
     */
  wsAlarmMoData({ commit, state }) {
    const { cId, gId } = getReqParam()
    websocketFn({ gId: gId, cId: cId, path: 'fireData6' }, (response) => {
      const { data } = response
      const parseData = JSON.parse(data)
      if (parseData.fireData) {
        parseData.fireData[0].forEach(item => {
          item.viewInfo = JSON.parse(item.viewInfo)
        })
      }
      console.log('wsAlarmMoData', parseData.fireData[0])
      commit('RESET_alarmMoData', parseData)
    })
  },
  /** ************     ws end        ****************/

  /**
     * 火灾自动报警系统
     * @param params
     * @returns {AxiosPromise}
     */
  getFireAlarmData({ commit, state }) {
    return new Promise(async(resolve, reject) => {
      const { cId, gId } = getReqParam()
      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fireData1' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          parseData.fireData[0].forEach(item => {
            item.viewInfo = JSON.parse(item.viewInfo)
          })
        }
        commit('RESET_freAlarmData', parseData)
      }).catch(error => {
        reject(error)
      })
      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fdc1' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          commit('RESET_freAlarmStatisticsData', parseData.fireData[0])
        }
      }).catch(error => {
        reject(error)
      })
      resolve()
    })
  },

  /**
     * 消防给水监测系统
     * @param params
     * @returns {AxiosPromise}
     */
  getFireWaterData({ commit, state }) {
    const { cId, gId } = getReqParam()
    return new Promise(async(resolve, reject) => {
      const setData = {}
      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fireData3' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          parseData.fireData[0].forEach(item => {
            item.viewInfo = JSON.parse(item.viewInfo)
            if (item.last7DayDatas) {
              const names = []; const values = []
              item.last7DayDatas.forEach((cItem) => {
                names.push(dateUtils.dateFormat(new Date(cItem.occurTime), 'yyyy-MM-dd'))
                // values.push(cItem.actVal.replace(item.viewInfo.unit,''))
                values.push(cItem.actVal.replace(item.viewInfo.unit, ''))
              })
              item.names = names
              item.values = values
            }
          })
        }
        setData.fireData3 = parseData
      }).catch(error => {
        reject(error)
      })

      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fireData4' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          parseData.fireData[0].forEach(item => {
            item.viewInfo = JSON.parse(item.viewInfo)
            if (item.last7DayDatas) {
              const names = []; const values = []
              item.last7DayDatas.forEach((cItem) => {
                names.push(dateUtils.dateFormat(new Date(cItem.occurTime), 'yyyy-MM-dd'))
                // values.push(cItem.actVal.replace(item.viewInfo.unit,''))
                values.push(cItem.actVal.replace(item.viewInfo.unit, ''))
              })
              item.names = names
              item.values = values
            }
          })
        }
        setData.fireData4 = parseData
      }).catch(error => {
        reject(error)
      })

      commit('RESET_fireWaterData', setData)

      const temp = []

      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fdc3' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          temp[0] = parseData.fireData[0]
        }
      }).catch(error => {
        reject(error)
      })

      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fdc4' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          temp[1] = parseData.fireData[0]
        }
      }).catch(error => {
        reject(error)
      })
      commit('RESET_fireWaterStatisticsData', temp)

      resolve()
    })
  },

  /**
     * 电气火灾智能监控系统
     * @param params
     * @returns {AxiosPromise}
     */
  getEleFireData({ commit, state }) {
    const { cId, gId } = getReqParam()
    return new Promise(async(resolve, reject) => {
      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fireData2' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          parseData.fireData[0].forEach(item => {
            item.viewInfo = JSON.parse(item.viewInfo)
          })
        }
        commit('RESET_eleFireData', parseData)
      }).catch(error => {
        reject(error)
      })

      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fdc2' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          commit('RESET_eleFireStatisticsData', parseData.fireData[0])
        }
      }).catch(error => {
        reject(error)
      })
      resolve()
    })
  },

  /**
     * 可燃气体检测预警系统
     * @param params
     * @returns {AxiosPromise}
     */
  getGasMoData({ commit, state }) {
    const { cId, gId } = getReqParam()
    return new Promise(async(resolve, reject) => {
      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fireData5' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          parseData.fireData[0].forEach(item => {
            item.viewInfo = JSON.parse(item.viewInfo)
          })
        }
        commit('RESET_gasMoData', parseData)
      }).catch(error => {
        reject(error)
      })

      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fdc5' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          commit('RESET_gasMoStatisticsData', parseData.fireData[0])
        }
      }).catch(error => {
        reject(error)
      })
      resolve()
    })
  },

  /**
     * 无线火灾报警监控系统
     * @param params
     * @returns {AxiosPromise}
     */
  getAlarmMoData({ commit, state }) {
    const { cId, gId } = getReqParam()
    return new Promise(async(resolve, reject) => {
      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fireData6' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          parseData.fireData[0].forEach(item => {
            item.viewInfo = JSON.parse(item.viewInfo)
          })
        }
        commit('RESET_alarmMoData', parseData)
      }).catch(error => {
        reject(error)
      })

      await getEquipmentMonitoringData({ gId: gId, cId: cId, path: 'fdc6' }).then(response => {
        const { data } = response
        const parseData = JSON.parse(data)
        if (parseData.fireData) {
          commit('RESET_alarmMoStatisticsData', parseData.fireData[0])
        }
      }).catch(error => {
        reject(error)
      })
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

